import { initializeApp } from 'firebase/app';
import { getDatabase } from 'firebase/database';
import { ConfigService } from '@nestjs/config';

export const initializeFirebaseApp = (configService: ConfigService) => {
  try {
    const firebaseConfig = {
      apiKey: configService.get<string>('FIREBASE_API_KEY'),
      authDomain: configService.get<string>('FIREBASE_AUTH_DOMAIN'),
      projectId: configService.get<string>('FIREBASE_PROJECT_ID'),
      storageBucket: configService.get<string>('FIREBASE_STORAGE_BUCKET'),
      messagingSenderId: configService.get<string>(
        'FIREBASE_MESSAGING_SENDER_ID',
      ),
      appId: configService.get<string>('FIREBASE_APP_ID'),
      measurementId: configService.get<string>('FIREBASE_MEASUREMENT_ID'),
      databaseURL: configService.get<string>('FIREBASE_DATABASE_URL'),
    };

    // Check if required Firebase config is available
    if (!firebaseConfig.projectId || firebaseConfig.projectId === 'placeholder-project') {
      console.warn('Firebase configuration not available, Firebase features will be disabled');
      return null;
    }

    const app = initializeApp(firebaseConfig);
    return getDatabase(app);
  } catch (error) {
    console.warn('Firebase initialization failed, Firebase features will be disabled:', error.message);
    return null;
  }
};

export const firebaseDataBase = (configService: ConfigService) =>
  initializeFirebaseApp(configService);
